@@ -1,3 +1,5 @@
+import logging
+
 from django.http import HttpResponse
 from django.views import View
 
@@ -6,6 +8,9 @@ from findmydevice.models import Device
 from findmydevice.services.device import get_device_by_token
 
 
+logger = logging.getLogger(__name__)
+
+
 class KeyView(View):
     """
     /key
@@ -13,12 +18,15 @@ class KeyView(View):
 
     def put(self, request):
         """
-        e.g:
-            {'Data': '1', 'IDT': 'LPYzPAFwLa8u'}
+        The WebPage/Client requests the private key.
         """
         put_data = parse_json(request)
         access_token = put_data['IDT']
-        # index = int(put_data['Data'])  # TODO: Use this index!
+
+        # XXX: The fmd WebPage sends "Data":"0" why?
+        index = put_data.get('Data')
+        if index != '0':
+            logger.warning('Get private key with Data!="0" ... Data is: %r', index)
 
         device: Device = get_device_by_token(token=access_token)
         privkey = device.privkey
