@@ -23,17 +23,17 @@ ALLOWED_HOSTS = ('127.0.0.1', '0.0.0.0', 'localhost')
 
 ###################################################################################################
 # Deny any not mocked requests
-
-
-def _unmocked_requests_error_message(request, response):
-    raise RuntimeError(
-        f'Unmocked request to {request.url} in tests, wrap with requests_mock.mock()!'
-    )
-
-
-fallback_mocker = requests_mock.Mocker()
-fallback_mocker.get(requests_mock.ANY, content=_unmocked_requests_error_message)
-fallback_mocker.__enter__()
+#
+#
+# def _unmocked_requests_error_message(request, response):
+#     raise RuntimeError(
+#         f'Unmocked request to {request.url} in tests, wrap with requests_mock.mock()!'
+#     )
+#
+#
+# fallback_mocker = requests_mock.Mocker()
+# fallback_mocker.get(requests_mock.ANY, content=_unmocked_requests_error_message)
+# fallback_mocker.__enter__()
 
 
 ###################################################################################################
