@@ -65,7 +65,7 @@ class AdminUserTests(HtmlAssertionMixin, TestCase):
 
     @mock.patch.object(timezone, 'now', MockDatetimeGenerator(datetime.timedelta(minutes=1)))
     def test_superuser_device(self):
-        device = baker.make(Device, uuid=UUID(int=1), name='Smartphone John')
+        device = baker.make(Device, uuid=UUID(int=1), short_id='xyz012', name='Smartphone John')
         baker.make(Location, device=device)
 
         self.client.force_login(self.superuser)
