@@ -1,3 +1,4 @@
+from itertools import count
 from unittest.mock import MagicMock, patch
 
 from django.template.defaulttags import CsrfTokenNode
@@ -26,3 +27,15 @@ class DefaultMocks(MocksBase):
             patch.object(CsrfTokenNode, 'render', return_value='MockedCsrfTokenNode'),
             # patch.object(context_processors, '__version__', new=version_mock),
         ]
+
+
+class ShortIdGenerator:
+    def __init__(self, ids: list):
+        self.ids = ids
+        self._pos = count(start=0)
+
+    def __call__(self):
+        try:
+            return self.ids[next(self._pos)]
+        except IndexError:
+            return self.ids[-1]
