@@ -3,11 +3,13 @@ from django.conf.urls import include, static
 from django.contrib import admin
 from django.urls import path
 
+from findmydevice.admin.fmd_admin_site import fmd_admin_site
+
 
 admin.autodiscover()
 
 urlpatterns = [  # Don't use i18n_patterns() here
-    path('admin/', admin.site.urls),
+    path('admin/', fmd_admin_site.urls),
     path('', include('findmydevice.urls')),
 ]
 
